/**
 * @author Design & Accessible Team ( Angie Radtke  )
 * @package Joomla
 * @subpackage Accessible-Template-Beez
 * @copyright (C) 2010 Open Source Matters, Inc. <https://www.joomla.org>
 * @license GNU/GPL, see LICENSE.txt
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */


body {
    background: #fff;
    color: #000000;
    font-size: 100.1%;
    padding: 0px;
    text-align: center;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

body.contentpane {
	width:auto;
	margin:10px;
	text-align: left;
}

img { border: 0 none; }
