/* This beautiful CSS-File has been crafted with LESS (lesscss.org) and compiled by simpLESS (wearekiss.com/simpless) */
body {
	background: #eee
}

h3 {
	color: #555
}

h2 a {
	text-decoration: none
}

h2, .moduletable h3, .items-leading h2 {
	border-bottom: solid 1px #ddd
}

.items-row h2 {
	border-top: solid 1px #ddd;
	border-bottom: solid 1px #ddd
}

a:link, a:visited {
	color: #c00
}

a:hover, a:active, a:focus {
	background: #c00;
	color: #FFF
}

.logoheader {
	background: #900;
	color: #FFF;
	min-height: 200px
}

#all {
	background: #fff;
	color: #555
}

#shadow #all {
	box-shadow: 0 20px 10px #555
}

#header ul.menu {
	background-color: #ddd;
	background-repeat: repeat-x;
	filter: progid:dximagetransform.microsoft.gradient(startColorstr=#eeeeee, endColorstr=#dddddd);
	background-image: -khtml-gradient(linear, left top, left bottom, from(#eee), to(#ddd));
	background-image: -moz-linear-gradient(top, #eee, #ddd);
	background-image: -ms-linear-gradient(top, #eee, #ddd);
	background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #eee), color-stop(100%, #ddd));
	background-image: -webkit-linear-gradient(top, #eee, #ddd);
	background-image: -o-linear-gradient(top, #eee, #ddd);
	background-image: linear-gradient(#eee, #ddd);
	border-color: #b2b2b2 #b2b2b2 #9f9f9f;
	text-shadow: 0 1px 1px rgba(255, 255, 255, .49);
	-webkit-font-smoothing: antialiased;
	box-shadow: 0 1px 0 rgba(255, 255, 255, .2) inset, 0 1px 2px rgba(0, 0, 0, .05);
	border: solid 1px #ddd;
	border: 1px solid #e5e5e5;
	text-transform: uppercase
}

#header ul.menu a:link, #header ul.menu a:visited {
	color: #333;
	display: inline-block;
	font-weight: 700;
	text-decoration: none;
	padding: 0 10px;
	margin: 0;
	display: inline-block;
	margin: 0 0 0;
	padding: 12px 15px;
	position: relative;
	border-right: 1px solid #ddd;
	box-shadow: 1px 0 0 #f5f5f5
}

.button, button, p.readmore a, #header input.button, .pagenav a:link, .pagenav a:visited, #advanced-search-toggle, .profile-edit a:link, .profile-edit a:visited, h3.js_heading, .article-info {
	background-color: #ddd;
	background-repeat: repeat-x;
	filter: progid:dximagetransform.microsoft.gradient(startColorstr=#ffffff, endColorstr=#dddddd);
	background-image: -khtml-gradient(linear, left top, left bottom, from(#fff), to(#ddd));
	background-image: -moz-linear-gradient(top, #fff, #ddd);
	background-image: -ms-linear-gradient(top, #fff, #ddd);
	background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #fff), color-stop(100%, #ddd));
	background-image: -webkit-linear-gradient(top, #fff, #ddd);
	background-image: -o-linear-gradient(top, #fff, #ddd);
	background-image: linear-gradient(#fff, #ddd);
	border-color: #b2b2b2 #b2b2b2 #9f9f9f;
	text-shadow: 0 1px 1px rgba(255, 255, 255, .49);
	-webkit-font-smoothing: antialiased;
	box-shadow: 0 1px 0 rgba(255, 255, 255, .2) inset, 0 1px 2px rgba(0, 0, 0, .05);
	color: #c00;
	border: solid 1px #ddd
}

.article-info {
	color: #555
}

table {
	border: solid 1px #ddd
}

table th a:link, table th a:visited {
	color: #fff
}

tr.odd, tr.cat-list-row1 {
	background: #f8f8f8
}

table tr:hover td {
	background: #FEFDE2
}

.button:hover, .button:active, .button:focus, button:hover, p.readmore a:hover, #header ul.menu a:hover, #header ul.menu a:active, #header ul.menu a:focus, .pagenav a:hover, .pagenav a:active, .pagenav a:focus, #advanced-search-toggle:hover, #advanced-search-toggle:active, #advanced-search-toggle:focus, .profile-edit a:hover, .profile-edit a:active, .profile-edit a:focus, #fontsize a:hover, #fontsize a:active, #fontsize a:focus, #mobile_select h2 a, table th, .logoheader {
	background-color: #c00;
	background-repeat: repeat-x;
	filter: progid:dximagetransform.microsoft.gradient(startColorstr=#cc0000, endColorstr=#990000);
	background-image: -khtml-gradient(linear, left top, left bottom, from(#c00), to(#900));
	background-image: -moz-linear-gradient(top, #c00, #900);
	background-image: -ms-linear-gradient(top, #c00, #900);
	background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #c00), color-stop(100%, #900));
	background-image: -webkit-linear-gradient(top, #c00, #900);
	background-image: -o-linear-gradient(top, #c00, #900);
	background-image: linear-gradient(#c00, #900);
	border-color: #900;
	color: #fff;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, .33);
	-webkit-font-smoothing: antialiased
}

.pagination span, .pagination span a:hover {
	color: #999;
	background-color: #f5f5f5
}

span.pagenav {
	background: #095197;
	color: #fff
}

.pagination-start span.pagenav, .pagination-prev span.pagenav, .pagination-end span.pagenav, .pagination-next span.pagenav {
	background-color: #f5f5f5;
	color: #444
}

ul.menu a:link, ul.menu a:visited {
	color: #444
}

.moduletable_menu {
	border: solid 1px #ddd;
	background: #f9f9f9
}

#header ul.menu {
	border: solid 1px #D5D5D5;
	box-shadow: 0 1px 0 #fff inset, 0 1px 5px rgba(0, 0, 0, .1)
}

#header ul.menu a {
	box-shadow: none;
	border-bottom: 0
}

ul.menu a:hover, ul.menu a:active, ul.menu a:focus {
	background-color: #F5F5F5;
	background-image: -moz-linear-gradient(center top, #fff, #e6e6e6);
	background-repeat: repeat-x;
	background: url(../images/arrow.png) no-repeat right center;
	color: #c00
}

ul.menu li.active a, ul.menu li.active ul li.active a, ul.menu li.active ul li.active ul li.active a, ul.menu li.active ul li.active ul li.active ul li.active a, ul.menu li.active ul li.active ul li.active ul li.active ul li.active a {
	font-weight: 700
}

ul.menu li.active ul li a, ul.menu li.active ul li.active ul li a, ul.menu li.active ul li.active ul li.active ul li a, ul.menu li.active ul li.active ul li.active ul li.active ul li a {
	font-weight: 400
}

ul.menu a {
	box-shadow: 0 1px 0 #fff;
	border-bottom: solid 1px #ddd;
	text-shadow: 0 1px 0 #fff
}

ul.menu ul a {
	background: #e5e5e5;
	margin-bottom: 1px
}

ul.menu ul ul ul a {
	background: #f5f5f5 url(../images/arrow.png) no-repeat 24px center
}

ul.menu ul ul ul ul a {
	background: #fff
}

.panel h3.pane-toggler a {
	background: url(../images/slider_plus.png) right top no-repeat;
	color: #333
}

.panel h3.pane-toggler-down a {
	background: url(../images/slider_minus.png) right top no-repeat;
	border-bottom: solid 1px #ddd;
	color: #333
}

ul.tabs li, dl.tabs dt h3 a:link, dl.tabs dt h3 a:visited {
	background: #f5f5f5 url(../images/nature/box.png) repeat-x
}

ul.tabs li a:link, ul.tabs li a:visited, dl.tabs dt a {
	color: #333;
	border: solid 1px #ddd;
	border-bottom: 0
}

ul.tabs li a:hover, ul.tabs li a:active, ul.tabs li a:focus {
	color: #000
}

.tabcontent, div.current {
	background: #fff;
	color: #000;
	border: solid 1px #ddd
}

.tabcontent .linkclosed {
	color: #000;
	border-bottom: solid 1px #e5e5e5
}

ul.tabs li a.linkopen, dl.tabs dt.open h3 a:link, dl.tabs dt.open h3 a:visited {
	background: #fff;
	color: #333;
	border-radius: 5px 5px 0 0
}

ul.tabs li a.linkclosed:hover, ul.tabs li a.linkclosed:active, ul.tabs li a.linkclosed:focus, ul.tabs li a.linkopen:hover, ul.tabs li a.linkopen:active, ul.tabs li a.linkopen:focus {
	background: #555;
	color: #fff
}

#footer-inner, #footer {
	background: #f5f5f5;
	box-shadow: 0 20px 10px #555
}

#footer {
	background: #555;
	max-width: 1025px;
	margin: 0 auto;
	box-shadow: 0 0 10px #555;
	color: #fff
}

#footer a {
	color: #fff;
	background: 0
}

#bottom a {
	background: 0
}

.box1 {
	border-right: solid 1px #ccc
}

.box3 {
	border-left: solid 1px #ccc
}

#bottom ul li a {
	background-image: none;
	padding-left: 0
}

#mobile_select h2 {
	border: 0;
	margin: -17px 0 0 0;
	padding: 0;
	background: #900;
	text-align: right
}

#mobile_select h2 a {
	display: inline-block;
	font-size: .8em;
	border-radius: 4px 4px 0 0;
	padding: 6px;
	font-size: .75em;
	margin-right: 5px
}

@media only screen and (max-width: 480px) {
	img {
		max-width: 100%;
		height: auto;
		border: 0;
		-ms-interpolation-mode: bicubic
	}

	#fontsize {
		display: none
	}

	#nav, #wrapper2, #wrapper, .cols-3 .column-1, .cols-3 .column-2, .cols-3 .column-3, #right, .box, #header form {
		float: none;
		width: 100%
	}

	#header {
		padding-top: 3em
	}

	#header form {
		margin: 0
	}

	.logoheader {
		background: #900;
		min-height: 100px;
		margin: 0
	}

	.box {
		border-left: 0 !important;
		border-bottom: solid 1px #ddd
	}

	#line {
		text-align: center;
		top: 0;
		right: auto;
		max-width: 100%;
		min-width: 100%;
		margin: 0 0;
		background: #c00
	}

	#header form input {
		float: none;
		margin-bottom: 4px
	}

	#menuwrapper {
		margin-top: 10px
	}

	#header ul.menu {
		position: relative;
		top: 0;
		left: 20px;
		right: 20px;
		margin: 0;
		width: 90%;
		border-radius: 4px
	}

	#header ul.menu li:first-child a {
		border-radius: 4px 4px 0 0
	}

	#header ul.menu li:last-child a {
		border-radius: 0 0 4px 4px
	}

	#header ul.menu li a:link, #header ul.menu li a:visited {
		display: block;
		padding: 6px 10px;
		border-bottom: solid 1px #ccc
	}
}
