/**
 * @author Design & Accessible Team ( Angie Radtke / Robert Deutz )
 * @package Joomla
 * @subpackage Accessible-Template-Beez
 * @copyright (C) 2010 Open Source Matters, Inc. <https://www.joomla.org>
 * @license GNU/GPL, see LICENSE.txt
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */


/* not ready */

h1,
#main h1
{
      font-size: 16pt;
      font-weight: bold;
      margin: 0.4em 0 0.5em 0;
      padding:0;
}

h2,
#main h2
{
      font-size: 14pt;
      font-weight: bold;
      margin: 0.2em 0 0.5em 0;
      padding: 0.3em 0.3em 0.3em 0;
}

h3
{
      font-size: 12pt;
      font-weight: bold;
      margin: 0.4em 0 0.2em 0;
}

/* Vermeidung von Seitenumbr�chen direkt nach einer �berschrift */
h1,
h2,
h3
{
      page-break-after: avoid;
}

body
{
  line-height:150%;
  font-family:Arial, Verdana, Helvetica, sans-serif;
}

p,
ul li, ol li,
address,
.category-desc,
table,
label,
dt,
dd
{
  font-size:10pt
}

address
{
	font-style:normal
}

.contact-address address span
{
	display:block
}

a
{
      font-weight: bold;
}

.unseen,
#line,
#header ul,
#breadcrumbs,
.article-info-term,
ul.actions,
#close,
.display-limit,
.moduletable_menu,
.moduletable_js,
.tabouter,
#bottom,
.pagination,
#footer,
#header-image

{
      display: none;
}

.skiplinks,
#suckerfish
{
	display:none !important
}

#header .logoheader
{
	border:0;
}

#header
{
      width: auto;
}

#all #back #header
{
padding-top:0
}


#all
{
      text-align:left;
      border:solid 0px #000
}

#back
{
  border:solid 0px #000;
  padding:0
}

#right
{
      display: block;
}

#header h1#logo
{
  font-size:20pt;
  font-weight:normal
}

#contentarea2,
#contentarea
{
	border: solid 0px #000;
	padding:0 !important
}

#main .blog-featured h1
{
  padding:0 !important;
}

#main #top
{
  overflow:hidden;
  margin-bottom:25pt;
  border:0
}

#main .categories-listalphabet ul
{
	padding-left:0
}

#main .categories-listalphabet ul li
{
	display:inline;
	padding:5pt;
	border-right:solid 1pt #ddd
}

#wrapper
{
	display:block;
	width:100% !important;
}

.item
{
  margin-bottom:30pt
}

.category-desc
{
	margin:15pt 0
}

.items-leading
{
	margin-bottom:30pt
}

#main .items-leading h2,
#main .item h2
{
      font-size: 14pt;
      font-weight: bold;
}

h2 a
{
	text-decoration:none
}

#main h1
{
	padding:5pt
}

#main .readmore a
{
  border:0 !important;
  padding-left:0 !important
}

.image-left {
	float:left;
	margin:0 15pt 5pt 0;
}

table
{
  margin:20pt 0;
  border-collapse:collapse;
  width:90%;
}

table td,
table th
{
  padding:2pt 5pt;
  border:solid 1pt #ddd
}

.items-more h3
{
	padding: 5pt 0;
	font-size:14pt
}

.items-more ol li a
{
	font-weight:normal
}

#nav a.readmore
{
  font-size:10pt
}

#nav .module_content
{
  margin-bottom:20pt;
  border:0 !important;
  padding:0 !important
}

#nav .moduletable ul.menu
{
	border:0;
	list-style-type:none;
	padding:0
}

#nav .moduletable ul.menu,
#nav .moduletable ul.menu ul,
#nav .moduletable ul.menu ul ul
{
	border:0;
	list-style-type:none
}

#nav .moduletable ul.menu ul,
#nav .moduletable ul.menu ul ul
{
	padding-left:15pt
}

#nav .moduletable ul.menu li
{
  border:0
}

#nav .moduletable ul.menu li a,
#nav .moduletable ul.menu li.active ul li a,
#nav .moduletable ul.menu li.active ul li.active ul li a
{
	text-decoration:none;
	border:solid 0px #000
}

ul#archive-items
{
	list-style-type:none;
	padding-left:0
}

.moduletable
{
  margin:20pt 0
}

dl.article-info
{
	line-height:120%;
	font-size:9pt
}

dl.article-info dd
{
	margin-left:0
}

h3.js_heading a img
{
  border:0
}

h3.js_heading,
#bottom h3,
.moduletable h3,
#nav h3
{
  font-size:12pt !important;
}

.category-list
{
	padding:0 !important;
}

.moduletable_js
{
  margin-bottom:20pt
}

.tabouter
{
  border:solid 0px ;
  overflow:hidden;
  margin:20pt 0
}

ul.tabs
{
  padding:0;
}

ul.tabs li.tab
{
  list-style-type:none;
  text-transform:uppercase;
  display:inline;
  border-right:solid 1pt #ddd;
  padding:2pt 10pt
}

ul.tabs li.tab a
{
  text-decoration:none;
}

.tabcontent
{
  padding:10pt
}

.contact-email div
{
	overflow:hidden
}

.contact-email label
{
	border:solid 0px #000;
	float:left;
	width:10em
}

.login div
{
	overflow:hidden
}

.login label
{
	float:left;
	width:10em
}

form fieldset dt
{
	clear:left;
	float:left;
	width:12em;
}

legend
{
	background:#fff;
	font-size:.85em
}

.phrases,
.only
{
	margin-bottom:15pt
}

.newsflash a.readmore:link
{
	border: solid 0pt ;
	font-weight:normal;
	font-size:0.8em;
	text-decoration:none
}

.stats dt
{
	float:left;
	width:10em
}

#footer-outer
{
  border:solid 0px;
  padding:0;
  background:none
}

#bottom
{
  text-align:left
}

#footer-outer #bottom .box .moduletable
{
  border-bottom:solid 1px #ddd;
  padding:10pt 0
}

#footer-outer #bottom .box1,
#footer-outer #bottom .box3
{
  border:0;
}

#bottom ul
{
  list-style-type:none;
  padding:0 !important
}

#bottom ul li
{
  border:solid 0px #c00
}
