/* not ready */

/* -- form validation */
.invalid { border-color: #B94A48;background:#F2DEDE}
label.invalid , label.required  span{ color: #B94A48; background:none
	}

/* -- Joomla edit buttons  Frontendediting*/
#editor-xtd-buttons {
	padding: 0px;
}
.edit tr:hover  td {background:#eee}
.button2-left,
.button2-right,
.button2-left div,
.button2-right div {
	float: left;
}

.button2-left a,
.button2-right a,
.button2-left span,
.button2-right span {
	display: block;
	float: left;
	color: #666;
	cursor: pointer;
}

.button2-left span,
.button2-right span {
	cursor: default;
	color: #999;
}

.button2-left .page a,
.button2-right .page a,
.button2-left .page span,
.button2-right .page span {
	padding: 0 6px;
}

.page span {
	color: #000;
	font-weight: bold;
}


.button2-left,
.button2-right {

	float: left;
	margin-left: 5px;
}


.edit .formelm-buttons {text-align:right}
.edit .formelm-buttons button {background:#D9EDF7; color:#095197;}
.edit .formelm-buttons button:hover {color:#D9EDF7; background:#095197;}
.modal-button:link,
.modal-button:visited,
.button2-left .readmore a:link,
.button2-left .readmore a:visited,
.button2-left .blank a:link,
.button2-left .blank a:visited
{ background-color: #D9EDF7;

	color:#095197;border:solid 1px #BCE8F1; border-top:0; border-radius:0 0 3px 3px;  text-decoration:none; padding:3px}
.button2-left a:hover,
.button2-left .blank a:hover,
.button2-left .readmore a:hover,
.button2-right a:hover {
	text-decoration: none;
	color: #fff;
	background:#095197;
}
.pull-right {
	float: right;
}
.pull-left {
	float: left;
}
.btn-toolbar .btn {
	-moz-border-bottom-colors: none;
	-moz-border-left-colors: none;
	-moz-border-right-colors: none;
	-moz-border-top-colors: none;
	background-color: #D9EDF7;
	border-image: none;
	border-radius: 0 0 3px 3px;
	color: #095197;
	padding: 3px;
	text-decoration: none;
}

div.toggle-editor {

}
/* Caption fixes */
.img_caption .left {
	float: left;
	margin-right: 1em;
}

.img_caption .right {
	float: right;
	margin-left: 1em;
}

.img_caption .left p {
	clear: left;
	text-align: center;
}

.img_caption .right p {
	clear: right;
	text-align: center;
}

.img_caption  {
	text-align: center!important;
}

.img_caption.none {
	margin-left:auto;
	margin-right:auto;
}
/* New captions */
figure {
	display: table;
}
figure.pull-center,
img.pull-center {
	margin-left: auto;
	margin-right: auto;
}
figcaption {
	display: table-caption;
	caption-side: bottom;
}
/* Calendar */
#jform_publish_down_btn {
	width: 18px;
	height: 18px;
	margin-left: 3px;
	background: url(../images/system/calendar.png) no-repeat;
	cursor: pointer;
	vertical-align: middle;
}
#jform_publish_up_btn {
	width: 18px;
	height: 18px;
	margin-left: 3px;
	background: url(../images/system/calendar.png) no-repeat;
	cursor: pointer;
	vertical-align: middle;
}


/* System Messages */

.error
{
	padding:0px;
	margin-bottom: 20px;
}

.error h2
{
	color:#000 !important;
	font-size:1.4em !important;
	text-transform:uppercase;
	padding:0 0 0 0px !important
}

#system-message dt
{
	font-weight: bold;
}
#system-message dd
{
	margin: 0 0 15px 0;
	font-weight: bold;
	text-indent: 0px;
	padding:0
}
#system-message dd ul
{
	color: #000;
	list-style: none;
	padding: 0px;
}
#system-message dd ul li
{
	line-height:1.5em
}

/* System Standard Messages */
#system-message dt.message
{
	position:absolute;
	top:-2000px;
	left:-3000px;
}

#system-message dd.message  ul
{
	background: #fff  url(../images/system/notice-info.png) no-repeat;
	padding-left:40px;
	padding: 10px 10px 10px 40px;
	border: 2px solid #90B203;
	border-radius:10px
}

#system-message dd.message ul li{background:none !important}

/* System Error Messages */
#system-message dt.error
{
	position:absolute;
	top:-2000px;
	left:-3000px;
}

#system-message dd.error ul
{
	background:#fff url(../images/system/notice-alert.png) no-repeat ;
	padding-left:40px;
 	padding: 10px 10px 10px 40px;
	border: 2px solid #990000;
	border-radius:10px

}



/* System Notice Messages */
#system-message dt.notice
{
	position:absolute;
	top:-2000px;
	left:-3000px;
}

#system-message dd.notice  ul
{
	background:#fff url(../images/system/notice-note.png) no-repeat ;
	padding-left:40px;
	padding: 10px 10px 10px 40px;
	border: 2px solid #FAA528;
	border-radius:10px

}
#system-message dd.notice ul { color: #000;margin:10px 0 }

#system-message
{
	margin-bottom: 0px;
	padding: 0;
}

#system-message dt
{
	font-weight: bold;
}

#system-message dd
{
	font-weight: bold;
	padding: 0;
}


.tip-wrap { background:#FEFDE2; font-size:0.8em ; padding:5px; border:solid 1px #ddd; border-radius:3px; box-shadow: 0 1px 5px #ccc }
.tip-title {font-weight:bold}

#all #upload-flash ul li a:hover,
#all .item a:hover span {
	background:#095197;
	color:#fff;
}


/* ##########################  user profile  ########################### */

#users-profile-core,
#users-profile-custom
{
	margin:10px 0 15px 0;
	padding:15px;
}

#users-profile-core dt,
#users-profile-custom dt
{
	float:left;
	width:12em;
	padding:3px 0;


}

#users-profile-core dd,
#users-profile-custom dd
{
	padding:3px 0;
}

#member-profile fieldset,
.registration fieldset
{
	margin:10px 0 15px 0;
	padding:15px;

}

#users-profile-core legend,
#users-profile-custom legend,
.profile-edit legend,
.registration legend
{
	font-weight:bold
}

.profile-edit form#member-profile fieldset dd,
.registration form#member-registration fieldset dd
{ float:none; padding:5px 0}

.profile-edit form#member-profile fieldset dd input,
.profile-edit form#member-profile fieldset dd select,
.registration form#member-registration fieldset dd input
{width:17em}
.profile-edit form#member-profile fieldset dt,
.registration form#member-registration fieldset dt
{padding:5px 5px 5px 0; width:13em}


span.optional
{font-size:0.9em}

/* ##########################  clearing  ########################### */
.clr {
	clear: both;
	overflow: hidden;
	height: 0;
}

/* ##########################  tooltip  ########################### */
.tooltip {
	position: absolute;
	z-index: 103000;
	display: block;
	visibility: visible;
	font-size: 11px;
	line-height: 1.4;
	opacity: 0;
	filter: alpha(opacity=0);
}
.tooltip.in {
	opacity: 0.8;
	filter: alpha(opacity=80);
}
.tooltip.top {
	margin-top: -3px;
	padding: 5px 0;
}
.tooltip.right {
	margin-left: 3px;
	padding: 0 5px;
}
.tooltip.bottom {
	margin-top: 3px;
	padding: 5px 0;
}
.tooltip.left {
	margin-left: -3px;
	padding: 0 5px;
}
.tooltip-inner {
	max-width: 200px;
	padding: 8px;
	color: #fff;
	text-align: left;
	text-decoration: none;
	background-color: #000;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}
.tooltip-arrow {
	position: absolute;
	width: 0;
	height: 0;
	border-color: transparent;
	border-style: solid;
}
.tooltip.top .tooltip-arrow {
	bottom: 0;
	left: 50%;
	margin-left: -5px;
	border-width: 5px 5px 0;
	border-top-color: #000;
}
.tooltip.right .tooltip-arrow {
	top: 50%;
	left: 0;
	margin-top: -5px;
	border-width: 5px 5px 5px 0;
	border-right-color: #000;
}
.tooltip.left .tooltip-arrow {
	top: 50%;
	right: 0;
	margin-top: -5px;
	border-width: 5px 0 5px 5px;
	border-left-color: #000;
}
.tooltip.bottom .tooltip-arrow {
	top: 0;
	left: 50%;
	margin-left: -5px;
	border-width: 0 5px 5px;
	border-bottom-color: #000;
}
.element-invisible {
	position: absolute;
	padding: 0;
	margin: 0;
	border: 0;
	height: 1px;
	width: 1px;
	overflow: hidden;
}
#filter-search {
	vertical-align: top;
}
.input-mini {
	width: 60px;
}

/* ##########################  popover  ########################### */
.popover {
	position: absolute;
	top: 0;
	left: 0;
	z-index: 1010;
	display: none;
	max-width: 276px;
	padding: 1px;
	text-align: left;
	background-color: #fff;
	-webkit-background-clip: padding-box;
	-moz-background-clip: padding;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0,0,0,0.2);
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	-webkit-box-shadow: 0 5px 10px rgba(0,0,0,0.2);
	-moz-box-shadow: 0 5px 10px rgba(0,0,0,0.2);
	box-shadow: 0 5px 10px rgba(0,0,0,0.2);
	white-space: normal;
}
.popover.top {
	margin-top: -10px;
}
.popover.right {
	margin-left: 10px;
}
.popover.bottom {
	margin-top: 10px;
}
.popover.left {
	margin-left: -10px;
}
.popover-title {
	margin: 0;
	padding: 8px 14px;
	font-size: 14px;
	font-weight: normal;
	line-height: 18px;
	background-color: #f7f7f7;
	border-bottom: 1px solid #ebebeb;
	-webkit-border-radius: 5px 5px 0 0;
	-moz-border-radius: 5px 5px 0 0;
	border-radius: 5px 5px 0 0;
}
.popover-title:empty {
	display: none;
}
.popover-content {
	padding: 9px 14px;
	min-height: 33px;
}
.popover .arrow,
.popover .arrow:after {
	position: absolute;
	display: block;
	width: 0;
	height: 0;
	border-color: transparent;
	border-style: solid;
}
.popover .arrow {
	border-width: 11px;
}
.popover .arrow:after {
	border-width: 10px;
	content: "";
}
.popover.top .arrow {
	left: 50%;
	margin-left: -11px;
	border-bottom-width: 0;
	border-top-color: #999;
	border-top-color: rgba(0,0,0,0.25);
	bottom: -11px;
}
.popover.top .arrow:after {
	bottom: 1px;
	margin-left: -10px;
	border-bottom-width: 0;
	border-top-color: #fff;
}
.popover.right .arrow {
	top: 50%;
	left: -11px;
	margin-top: -11px;
	border-left-width: 0;
	border-right-color: #999;
	border-right-color: rgba(0,0,0,0.25);
}
.popover.right .arrow:after {
	left: 1px;
	bottom: -10px;
	border-left-width: 0;
	border-right-color: #fff;
}
.popover.bottom .arrow {
	left: 50%;
	margin-left: -11px;
	border-top-width: 0;
	border-bottom-color: #999;
	border-bottom-color: rgba(0,0,0,0.25);
	top: -11px;
}
.popover.bottom .arrow:after {
	top: 1px;
	margin-left: -10px;
	border-top-width: 0;
	border-bottom-color: #fff;
}
.popover.left .arrow {
	top: 50%;
	right: -11px;
	margin-top: -11px;
	border-right-width: 0;
	border-left-color: #999;
	border-left-color: rgba(0,0,0,0.25);
}
.popover.left .arrow:after {
	right: 1px;
	border-right-width: 0;
	border-left-color: #fff;
	bottom: -10px;
}

/* Bootstrap overrides anhiliation
 * @since 3.2
 */
body#shadow {
    line-height: 1.5em;
}
body .nav-pills > .active > a, body .nav-pills > .active > a:hover, body .nav-pills > .active > a:focus {
    background-color: transparent;
}
body .nav-pills > li > a {
    border-radius: 0px;
    line-height: 1.5em;
}
body a {
    text-decoration: underline;
}
body input[type="text"].search-query {
    line-height: 1.5em;
    height: auto;
    border-radius: 4px;

}
/* Text alignments */
.text-left {
	text-align: left;
}
.text-right {
	text-align: right;
}
.text-center {
	text-align: center;
}

/* Component pop-up */
.container-popup {
	padding: 28px 10px 10px 10px;
}
