/*
 * @author ( Angie Radtke )
*/


/* ##########################  general  ########################### */

body
{
	font-family: arial, helvetica, sans-serif;
	background:#fff;
	color:#444
}

h3 {
	color: #555
}

h2 a {
	text-decoration: none
}

h2, .moduletable h3 {
	border-bottom: solid 1px #ddd;
}

.items-row h2
{border-top: solid 1px #ddd;
}

a:link,
a:visited
{
	color:#0A5E69
}

a:hover,
a:active,
a:focus
{
	background:#0A5E69;
	color:#FFF;
}

/* ##########################  logo  ########################### */

.logoheader
{
	border-top:solid 1px transparent;
	color:#fff;
	max-width: 1050px;
	margin:37px auto;
	min-height:20px;
	margin-bottom:0;

}
.logoheader h1#logo
{padding:20px 10px 0px 10px; }
.logoheader h1#logo  span.header1 {padding:0}

/* ##########################  header  ########################### */

#all {padding-top:13em}
#line { position:relative; max-width:1050px; margin:0 auto; text-align:right; right:0;  top:0em}
#header
{
	background: #004746; /* Old browsers */
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#185359", endColorstr="#007774");
	background: -moz-linear-gradient(top,  #004746 0%, #0a5e69 25%, #185359 18%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#004746), color-stop(25%,#0a5e69), color-stop(18%,#185359)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #004746 0%,#0a5e69 25%,#185359 18%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #004746 0%,#0a5e69 25%,#185359 18%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #004746 0%,#0a5e69 25%,#185359 18%); /* IE10+ */
	background: linear-gradient(top,  #004746 0%,#0a5e69 25%,#185359 18%); /* W3C */
	position:absolute;
	left:0;
	top:0;
	width:99.9%;
	padding:0;
}
/* green background */
.button:hover, button:hover, p.readmore a:hover,
.pagenav a:hover, .pagenav a:active,  .pagenav a:focus,  #advanced-search-toggle:hover,  #advanced-search-toggle:active,  #advanced-search-toggle:focus,
.profile-edit a:hover, .profile-edit a:active, .profile-edit a:focus,
#fontsize a:hover,  #fontsize a:active,  #fontsize a:focus,#mobile_select h2 a
	{

	color: #fff;
	background: #008885; /* Old browsers */


	background-color: hsl(165, 27%, 27%) ;
	 background-repeat: repeat-x;
	  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#008885", endColorstr="#004746");
	   background-image: -khtml-gradient(linear, left top, left bottom, from(#008885), to(#004746));
	   background-image: -moz-linear-gradient(top, #008885, #004746);
background-image: -ms-linear-gradient(top, #008885, #004746);
background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #008885), color-stop(100%, #004746));
background-image: -webkit-linear-gradient(top, #008885, #004746);
background-image: -o-linear-gradient(top, #008885, #004746);
background-image: linear-gradient(#008885, #004746);
border-color: #004746 #004746 hsl(165, 27%, 22.5%);
text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.29);
-webkit-font-smoothing: antialiased;
}

/* ++++++++++++++ header  menu ++++++++++++++ */

#header ul.menu
{

	border:0;
	list-style-type:none;
	border-radius:0;
	overflow:hidden;
	margin:0 auto ;
	text-align:right;
	position:absolute;
	top:0;
	right:10px;
}

#header ul.menu li
{
	border:0;

}
#header ul.menu a {
	box-shadow:none;
	border-bottom:0
	}
#header ul.menu li a:link,
#header ul.menu li a:visited
{
	color:#fff;
	border:0;
	border-right:solid 1px #237D85;
	box-shadow: none;
	background:transparent;
	padding:10px ;
	display:inline-block
}
#header ul.menu li:first-child a {border-radius:0}
#header ul.menu li a:hover,
#header ul.menu li a:active,
#header ul.menu li a:focus
{
	color:#333;
	background:#bddfb3;
	padding:10px
}

#header ul li.active a:link,
#header ul li.active a:visited
{
	color:#333;
	border-right:solid 1px #237D85;
	background:#bddfb3;
	padding: 10px  ;

}

#fontsize a , #fontsize h3 {color:#fff}
/*  grey background */
.button, button , p.readmore a ,
 .pagenav a:link, .pagenav a:visited, #advanced-search-toggle , .profile-edit a:link,.profile-edit a:visited,  h3.js_heading
 {
	background-color: #F5F5F5;
	background-image: -moz-linear-gradient(center top, #FFFFFF, #E6E6E6);
	background-repeat: repeat-x;
	border:solid 1px #ccc;
	box-shadow: 0 1px 0 rgba(255, 255, 255, 0.2) inset, 0 1px 2px
		rgba(0, 0, 0, 0.05);
	color: #004746;
}


/* ++++++++++++++++++++++  navigation  ++++++++++++++++++++++++++  */

.moduletable_menu {
	border: solid 1px #ddd;
	background: #f9f9f9;

}
#header ul.menu {
	border-color: #D5D5D5;
}

ul.menu a:hover,
ul.menu a:active,
ul.menu a:focus {
	background-color: #F5F5F5;
	background-image: -moz-linear-gradient(center top, #FFFFFF, #E6E6E6);
	background-repeat: repeat-x;
	background: url(../images/arrow.png) no-repeat right center;
	color: #004746;

}


/* ++++++++++++++++   highlighting active menuitem  +++++++++++++++++++ */

ul.menu li.active a,ul.menu  li.active ul li.active a,
ul.menu  li.active ul li.active  ul li.active a,
ul.menu  li.active ul li.active  ul li.active ul li.active  a ,
ul.menu  li.active ul li.active  ul li.active ul li.active ul li.active a
{font-weight:bold; }
ul.menu  li.active ul li a,
ul.menu  li.active ul li.active  ul li a,
ul.menu  li.active ul li.active  ul li.active ul li  a,
ul.menu  li.active ul li.active  ul li.active ul li.active ul li a
{font-weight:normal}

ul.menu a
{
	box-shadow:0 1px 0 #fff;
	border-bottom:solid 1px #ddd;

}

ul.menu ul a {
	background: #e5e5e5;
	margin-bottom:1px
}

ul.menu ul ul ul a {
	background: #f5f5f5 url(../images/arrow.png) no-repeat 24px center;

}

ul.menu ul ul ul ul a {
	background: #fff;
}

/* +++++++++++++++++  content  +++++++++++++++ */


.article-info {
	background-color: #fbfbfb;
	background-image: -moz-linear-gradient(top, #ffffff, #f5f5f5);
	background-image: -ms-linear-gradient(top, #ffffff, #f5f5f5);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff),
		to(#f5f5f5) );
	background-image: -webkit-linear-gradient(top, #ffffff, #f5f5f5);
	background-image: -o-linear-gradient(top, #ffffff, #f5f5f5);
	background-image: linear-gradient(top, #ffffff, #f5f5f5);
	background-repeat: repeat-x;
	filter: progid : DXImageTransform.Microsoft.gradient ( startColorstr =
		'#ffffff', endColorstr = '#f5f5f5', GradientType = 0 );
	border: 1px solid #ddd;
	-webkit-box-shadow: inset 0 1px 0 #ffffff;
	-moz-box-shadow: inset 0 1px 0 #ffffff;
	box-shadow: inset 0 1px 0 #ffffff;
}

ul.menu a:link,ul.menu a:visited {
	color: #444;
}


#footer-inner, #footer , #footer-outer {
	background: #f5f5f5;
}
#footer-sub {background:#555;}
#footer {background:#555; max-width:1025px; margin:0 auto; }
#footer a {color:#fff}

.box1
{border-right:solid 1px #ccc}
.box3
{border-left:solid 1px #ccc}
#bottom  ul li a
{background-image:none;
padding-left:0}

/* +++++++++++++++++++++++  SLIDER  ++++++++++++++++++++  */

.panel h3.pane-toggler a
{
	background: url(../images/slider_plus.png) right  top no-repeat;
	color:#333
}
.panel h3.pane-toggler-down a
{
	background: url(../images/slider_minus.png) right  top no-repeat;
	border-bottom:solid 1px #ddd;
	color:#333
}

/*  +++++++++++++++++   Tabs ++++++++++++++++++++++  */

ul.tabs li,
dl.tabs dt h3 a:link,
dl.tabs dt h3 a:visited
{
	background:#f5f5f5 url(../images/nature/box.png) repeat-x;

}
ul.tabs li a:link,
ul.tabs li a:visited,
dl.tabs dt a
{
	color:#333;
	border:solid 1px #ddd; border-bottom:0
}

ul.tabs li a:hover,
ul.tabs li a:active,
ul.tabs li a:focus
{
	color:#000
}

.tabcontent, div.current
{
	background:#fff;
	color:#000;
	border:solid 1px #ddd;
}

.tabcontent .linkclosed
{
	color:#000;
	border-bottom:solid 1px #e5e5e5;
}

ul.tabs li a.linkopen,
dl.tabs dt.open  h3 a:link,
dl.tabs dt.open  h3 a:visited
{
	background:#fff;
	color:#333;
	border-radius: 5px 5px 0px 0px;
}

ul.tabs li a.linkclosed:hover,
ul.tabs li a.linkclosed:active,
ul.tabs li a.linkclosed:focus,
ul.tabs li a.linkopen:hover,
ul.tabs li a.linkopen:active,
ul.tabs li a.linkopen:focus
{
	background:#555;
	color:#fff
}


/* +++++++++++++++++  Pagination +++++++++++++++ */

.pagination span,
.pagination span  a:hover {
	color: #999999;
	background-color: #f5f5f5;
}

/* active item */
span.pagenav
{
background:#0A5E69;
color:#fff
}

.pagination-start span.pagenav,
.pagination-prev  span.pagenav,
.pagination-end span.pagenav,
.pagination-next span.pagenav

{
background-color:#f5f5f5;
color:#444
}

/* +++++++++++++  table display  Catgegories table, contact etc, ++++++++++++++++++++* */

table {border:solid 1px #ddd}
table th
 {
	background-color: #0A5E69;;
	color: #fff;
}
table th a:link,
table th a:visited
{color:#fff}
tr.odd, tr.cat-list-row1 {background:#f8f8f8}
table  tr:hover td,
table tr:hover th {
  background-color: #FEFDE2;
}

/* responsive */
#mobile_select h2 {border:0; margin:-17px 0 0 0; padding:0; background:#004746;text-align:right}
#mobile_select h2 a {
display:inline-block;
font-size:0.8em;
border-radius:4px 4px 0 0;
padding:6px;
font-size:0.75em;
margin-right:5px;
}

@media only screen and (max-width: 480px) {

	  img {
  max-width: 100%;
  height: auto;
  border: 0;
  -ms-interpolation-mode: bicubic;
}

	#fontsize{display:none}
	#nav,#wrapper2,#wrapper,.cols-3 .column-1,.cols-3 .column-2,.cols-3 .column-3,#right,.box,#header form
		{
		float: none;
		width: 100%
	}
	#header {padding-top:3em; position:relative; margin:0; max-height:auto !important; }
	#header form  {margin:0}
	#all {padding-top:0}
	.logoheader {background:#004746 ; min-height:100px;margin:0 }
	.box {
		border-left: 0 !important;
		border-bottom: solid 1px #ddd;
	}
	#line {
		text-align: center;
		top: 0;
		right: auto;
		max-width: 100% ;
		min-width:100%;
		margin: 0 0px;
		background:#0A5E69;
		position:absolute
	}
	#header form input {
		float: none; margin-bottom:4px
	}
	#menuwrapper { margin-top:10px; background:#fff; padding:10px; width:97%}
	#header ul.menu {position:relative; top:0;left:20px; right:20px; margin:0; width:90%; border-radius:4px; text-align:left; border:0}
	#header ul.menu li:first-child a {border-radius: 4px 4px 0 0}
	#header ul.menu li:last-child a {border-radius:0 0 4px 4px }
	#header ul.menu li a:link,
	#header ul.menu li a:visited {
		display: block;
		padding: 6px 10px;
		border-right:0;
		border-bottom: solid 1px #ccc;
		background:#eee;
		color:#444
	}
}

@media only screen and (min-width: 600px) {
}

@media only screen and (min-width: 768px) {
}

@media only screen and (min-width: 992px) {
}

@media only screen and (min-width: 1382px) { /* Styles */
}

@media only screen and (-webkit-min-device-pixel-ratio: 1.5) , only screen and
		(min--moz-device-pixel-ratio: 1.5) , only screen and
	(min-device-pixel-ratio: 1.5) { /* Styles */
}
